#ifndef NT2_INCLUDE_FUNCTIONS_MINUS_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_MINUS_HPP_INCLUDED

#include <nt2/operator/include/functions/minus.hpp>

#endif
